@@ -60,6 +60,7 @@
 ( "bcmx"                    , "file_type_outlook"                 ) ,
 ( "berksfile"               , "file_type_chef"                    ) ,
 ( "berksfile.lock"          , "file_type_chef"                    ) ,
+( "bat"                     , "file_type_bat"                     ) ,
 ( "bin"                     , "file_type_binary"                  ) ,
 ( "bitbucket-pipelines.yml" , "file_type_bitbucketpipeline"       ) ,
 ( "bithoundrc"              , "file_type_bithound"                ) ,
@@ -242,6 +243,7 @@
 ( "hl"                      , "file_type_binary"                  ) ,
 ( "hpp"                     , "file_type_cppheader"               ) ,
 ( "hs"                      , "file_type_haskell"                 ) ,
+( "html"                    , "file_type_html"                    ) ,
 ( "htmlhintrc"              , "file_type_htmlhint"                ) ,
 ( "husky.config.js"         , "file_type_husky"                   ) ,
 ( "huskyrc"                 , "file_type_husky"                   ) ,
@@ -296,6 +298,7 @@
 ( "json"                    , "file_type_json_official"           ) ,
 ( "json-ld"                 , "file_type_jsonld"                  ) ,
 ( "jsonld"                  , "file_type_jsonld"                  ) ,
+( "js"                      , "file_type_js"                      ) ,
 ( "jsp"                     , "file_type_jsp"                     ) ,
 ( "jss"                     , "file_type_jss"                     ) ,
 ( "js.snap"                 , "file_type_jest_snapshot"           ) ,
@@ -456,6 +459,7 @@
 ( "P"                       , "file_type_prolog"                  ) ,
 ( "pfx"                     , "file_type_cert"                    ) ,
 ( "phar"                    , "file_type_php3"                    ) ,
+( "php"                     , "file_type_php3"                    ) ,
 ( "php1"                    , "file_type_php3"                    ) ,
 ( "php2"                    , "file_type_php3"                    ) ,
 ( "php3"                    , "file_type_php3"                    ) ,
@@ -512,6 +516,7 @@
 ( "prisma"                  , "file_type_prisma"                  ) ,
 ( "pro"                     , "file_type_prolog"                  ) ,
 ( "procfile"                , "file_type_procfile"                ) ,
+( "properties"              , "file_type_config"                  ) ,
 ( "psd"                     , "file_type_photoshop2"              ) ,
 ( "psd1"                    , "file_type_powershell_psd2"         ) ,
 ( "psm1"                    , "file_type_powershell_psm2"         ) ,
@@ -600,6 +605,7 @@
 ( "spe"                     , "file_type_spacengine"              ) ,
 ( "sqlite3"                 , "file_type_sqlite"                  ) ,
 ( "sqlite"                  , "file_type_sqlite"                  ) ,
+( "sql"                     , "file_type_sql"                     ) ,
 ( "src"                     , "file_type_cert"                    ) ,
 ( "sss"                     , "file_type_sss"                     ) ,
 ( "sst"                     , "file_type_cert"                    ) ,
@@ -608,6 +614,7 @@
 ( "stylelintcache"          , "file_type_stylelint"               ) ,
 ( "stylelintignore"         , "file_type_stylelint"               ) ,
 ( "stylelintrc"             , "file_type_stylelint"               ) ,
+( "jenkinsfile"             , "file_type_jenkins"                 ) ,
 ( "stylish-haskell.yaml"    , "file_type_stylish_haskell"         ) ,
 ( "svg"                     , "file_type_svg"                     ) ,
 ( "svi"                     , "file_type_video"                   ) ,
@@ -636,10 +643,12 @@
 ( "tslint.yml"              , "file_type_tslint"                  ) ,
 ( "ts.snap"                 , "file_type_jest_snapshot"           ) ,
 ( "tst"                     , "file_type_test"                    ) ,
+( "tsx"                     , "file_type_typescript"              ) ,
 ( "tsx.snap"                , "file_type_jest_snapshot"           ) ,
 ( "tt2"                     , "file_type_tt"                      ) ,
 ( "tta"                     , "file_type_audio"                   ) ,
 ( "ttf"                     , "file_type_font"                    ) ,
+( "txt"                     , "file_type_text"                    ) ,
 ( "types.ps1xml"            , "file_type_powershell_types"        ) ,
 ( "unibeautify.config.js"   , "file_type_unibeautify"             ) ,
 ( "unibeautifyrc"           , "file_type_unibeautify"             ) ,
@@ -684,6 +693,7 @@
 ( "xls"                     , "file_type_excel2"                  ) ,
 ( "xlsm"                    , "file_type_excel2"                  ) ,
 ( "xlsx"                    , "file_type_excel2"                  ) ,
+( "xml"                     , "file_type_xml"                     ) ,
 ( "xsf"                     , "file_type_infopath"                ) ,
 ( "xsn"                     , "file_type_infopath"                ) ,
 ( "xtp2"                    , "file_type_infopath"                ) ,
