@@ -136,7 +136,7 @@ impl App {
         if let Some(path) = con.initial_file.as_ref() {
             // open initial_file in preview
             let preview_state = Box::new(PreviewState::new(
-                path.to_path_buf(),
+                path.clone(),
                 InputPattern::none(),
                 None,
                 con.initial_tree_options.clone(),
@@ -282,7 +282,7 @@ impl App {
                 con,
             };
             if let Some(pos) = time!("display panel", panel.display(w, &disc)?,) {
-                cursor_pos = Some(pos)
+                cursor_pos = Some(pos);
             }
         }
 
@@ -328,12 +328,12 @@ impl App {
     fn apply_command(
         &mut self,
         w: &mut W,
-        cmd: Command,
+        cmd: &Command,
         panel_skin: &PanelSkin,
         app_state: &mut AppState,
         con: &mut AppContext,
     ) -> Result<(), ProgramError> {
-        use CmdResult::*;
+        info!("app applying command: {:?}", &cmd);
         let mut error: Option<String> = None;
         let mut new_active_panel_idx = None;
         let is_input_invocation = cmd.is_verb_invocated_from_input();
@@ -346,13 +346,13 @@ impl App {
         };
         let cmd_result = self
             .mut_panel()
-            .apply_command(w, &cmd, app_state, &app_cmd_context)?;
+            .apply_command(w, cmd, app_state, &app_cmd_context)?;
         info!("cmd_result: {:?}", &cmd_result);
         match cmd_result {
-            ApplyOnPanel { id } => {
+            CmdResult::ApplyOnPanel { id } => {
                 if let Some(idx) = self.panel_id_to_idx(id) {
-                    if let DisplayError(txt) =
-                        self.panels[idx].apply_command(w, &cmd, app_state, &app_cmd_context)?
+                    if let CmdResult::DisplayError(txt) =
+                        self.panels[idx].apply_command(w, cmd, app_state, &app_cmd_context)?
                     {
                         // we should probably handle other results
                         // which implies the possibility of a recursion
@@ -364,7 +364,7 @@ impl App {
                     warn!("no panel found for ApplyOnPanel");
                 }
             }
-            ClosePanel {
+            CmdResult::ClosePanel {
                 validate_purpose,
                 panel_ref,
                 clear_cache,
@@ -415,7 +415,7 @@ impl App {
                     self.quitting = true;
                 }
             }
-            ChangeLayout(instruction) => {
+            CmdResult::ChangeLayout(instruction) => {
                 con.layout_instructions.push(instruction);
                 Areas::resize_all(
                     self.panels.as_mut_slice(),
@@ -424,20 +424,23 @@ impl App {
                     self.preview_panel.is_some(),
                 );
             }
-            DisplayError(txt) => {
+            CmdResult::DisplayError(txt) => {
                 error = Some(txt);
             }
-            ExecuteSequence { sequence } => {
+            CmdResult::ExecuteSequence { sequence } => {
+                if is_input_invocation {
+                    self.mut_panel().clear_input();
+                }
                 self.tx_seqs.send(sequence).unwrap();
             }
-            HandleInApp(internal) => {
+            CmdResult::HandleInApp(internal) => {
                 debug!("handling internal {internal:?} at app level");
                 match internal {
                     Internal::escape => {
                         let mode = self.panel().state().get_mode();
                         let cmd = self.mut_panel().input.escape(con, mode);
                         debug!("cmd on escape: {cmd:?}");
-                        self.apply_command(w, cmd, panel_skin, app_state, con)?;
+                        self.apply_command(w, &cmd, panel_skin, app_state, con)?;
                     }
                     Internal::focus_staging_area_no_open => {
                         new_active_panel_idx = self
@@ -551,27 +554,27 @@ impl App {
                                 "unhandled propagated internal. internal={internal:?} cmd={cmd:?}"
                             );
                         } else {
-                            self.apply_command(w, cmd, panel_skin, app_state, con)?;
+                            self.apply_command(w, &cmd, panel_skin, app_state, con)?;
                         }
                     }
                 }
             }
-            Keep => {
+            CmdResult::Keep => {
                 if is_input_invocation {
                     self.mut_panel().clear_input_invocation(con);
                 }
             }
-            Message(md) => {
+            CmdResult::Message(md) => {
                 if is_input_invocation {
                     self.mut_panel().clear_input_invocation(con);
                 }
                 self.mut_panel().set_message(md);
             }
-            Launch(launchable) => {
+            CmdResult::Launch(launchable) => {
                 self.launch_at_end = Some(*launchable);
                 self.quitting = true;
             }
-            NewPanel {
+            CmdResult::NewPanel {
                 state,
                 purpose,
                 direction,
@@ -581,7 +584,7 @@ impl App {
                     error = Some(s);
                 }
             }
-            NewState { state, message } => {
+            CmdResult::NewState { state, message } => {
                 self.mut_panel().clear_input();
                 self.mut_panel().push_state(state);
                 if let Some(md) = message {
@@ -591,7 +594,7 @@ impl App {
                         .refresh_input_status(app_state, &app_cmd_context);
                 }
             }
-            PopState => {
+            CmdResult::PopState => {
                 if is_input_invocation {
                     self.mut_panel().clear_input();
                 }
@@ -603,7 +606,7 @@ impl App {
                     self.quitting = true;
                 }
             }
-            PopStateAndReapply => {
+            CmdResult::PopStateAndReapply => {
                 if is_input_invocation {
                     self.mut_panel().clear_input();
                 }
@@ -616,15 +619,15 @@ impl App {
                         con,
                     };
                     self.mut_panel()
-                        .apply_command(w, &cmd, app_state, &app_cmd_context)?;
+                        .apply_command(w, cmd, app_state, &app_cmd_context)?;
                 } else if con.quit_on_last_cancel {
                     self.quitting = true;
                 }
             }
-            Quit => {
+            CmdResult::Quit => {
                 self.quitting = true;
             }
-            RefreshState { clear_cache } => {
+            CmdResult::RefreshState { clear_cache } => {
                 info!("refreshing, clearing cache={clear_cache}");
                 if is_input_invocation {
                     self.mut_panel().clear_input_invocation(con);
@@ -709,7 +712,7 @@ impl App {
         (len * x as usize) / (self.screen.width as usize + 1)
     }
 
-    /// handle CmdResult::NewPanel
+    /// handle `CmdResult::NewPanel`
     fn new_panel(
         &mut self,
         state: Box<dyn PanelState>,
@@ -882,14 +885,15 @@ impl App {
 
         if let Some(raw_sequence) = &con.cmd() {
             self.tx_seqs
-                .send(Sequence::new_local(raw_sequence.to_string()))
-                .unwrap();
+                .send(Sequence::new_local((*raw_sequence).to_string()))
+                .map_err(|e| ProgramError::Internal {
+                    details: format!("failed to send initial command: {e}"),
+                })?;
         }
 
         #[cfg(unix)]
         let _server = con
-            .launch_args
-            .listen
+            .server_name
             .as_ref()
             .map(|server_name| {
                 let shared_root = Arc::new(Mutex::new(app_state.root.clone()));
@@ -937,7 +941,7 @@ impl App {
                 Either::First(Some(event)) => {
                     //info!("event: {:?}", &event);
                     if let Some(key_combination) = event.key_combination {
-                        debug!("key combination: {}", key_combination);
+                        debug!("key combination: {key_combination}");
                     }
                     let mut handled = false;
 
@@ -964,9 +968,10 @@ impl App {
 
                     // event handled by the panel
                     if !handled {
-                        let cmd = self.mut_panel().add_event(w, event, &app_state, con)?;
-                        debug!("command after add_event: {:?}", &cmd);
-                        self.apply_command(w, cmd, &skin.focused, &mut app_state, con)?;
+                        debug!("not handled at app level: {:?}", &event);
+                        let cmd = self.mut_panel().add_event(w, &event, &app_state, con)?;
+                        info!("command after add_event: {:?}", &cmd);
+                        self.apply_command(w, &cmd, &skin.focused, &mut app_state, con)?;
                     }
 
                     event_source.unblock(self.quitting);
@@ -976,13 +981,13 @@ impl App {
                     // when the input thread is properly closed
                     break;
                 }
-                Either::Second(Some(raw_sequence)) => {
-                    debug!("got command sequence: {:?}", &raw_sequence);
-                    for (input, arg_cmd) in raw_sequence.parse(con)? {
+                Either::Second(Some(sequence)) => {
+                    info!("got command sequence: {:?}", &sequence);
+                    for (input, arg_cmd) in sequence.parse(con)? {
                         if !matches!(&arg_cmd, Command::Internal { .. }) {
                             self.mut_panel().set_input_content(&input);
                         }
-                        self.apply_command(w, arg_cmd, &skin.focused, &mut app_state, con)?;
+                        self.apply_command(w, &arg_cmd, &skin.focused, &mut app_state, con)?;
                         if self.quitting {
                             return Ok(self.launch_at_end.take());
                         }
@@ -999,10 +1004,9 @@ impl App {
             }
         }
         terminal::reset_title(w, con);
-        kitty::manager()
-            .lock()
-            .unwrap()
-            .erase_images_before(w, usize::MAX)?;
+        if let Ok(mut manager) =  kitty::manager().lock() {
+             manager.erase_images_before(w, usize::MAX)?;
+        }
         w.flush()?;
 
         Ok(self.launch_at_end.take())
@@ -1015,6 +1019,6 @@ impl App {
 fn clear_caches() {
     file_sum::clear_cache();
     git::clear_status_computer_cache();
-    #[cfg(any(target_os = "macos", target_os = "linux"))]
+    #[cfg(any(target_os = "macos", target_os = "linux", target_os = "windows"))]
     crate::filesystems::clear_cache();
 }
