@@ -2,16 +2,22 @@ use {
     super::*,
     crate::{
         app::Mode,
-        cli::{Args, TriBool},
+        cli::{
+            Args,
+            TriBool,
+        },
         conf::*,
         content_search,
         display::LayoutInstructions,
         errors::*,
         file_sum,
         icon::*,
-        kitty::TransmissionMedium,
-        pattern::SearchModeMap,
+        kitty::{
+            KittyGraphicsDisplay,
+            TransmissionMedium,
+        },
         path::SpecialPaths,
+        pattern::SearchModeMap,
         preview::PreviewTransformers,
         skin::ExtColorMap,
         syntactic::SyntaxTheme,
@@ -20,17 +26,22 @@ use {
     },
     crokey::crossterm::tty::IsTty,
     std::{
-        convert::{TryFrom, TryInto},
+        convert::{
+            TryFrom,
+            TryInto,
+        },
         io,
         num::NonZeroUsize,
-        path::{Path, PathBuf},
+        path::{
+            Path,
+            PathBuf,
+        },
     },
 };
 
 /// The container that can be passed around to provide the configuration things
 /// for the whole life of the App
 pub struct AppContext {
-
     /// Whether the application is running in a normal TTY context
     pub is_tty: bool,
 
@@ -50,7 +61,7 @@ pub struct AppContext {
     /// all the arguments specified at launch
     pub launch_args: Args,
 
-    /// the "launch arguments" found in the default_flags
+    /// the "launch arguments" found in the `default_flags`
     /// of the config file(s)
     pub config_default_args: Option<Args>,
 
@@ -100,13 +111,16 @@ pub struct AppContext {
     /// and there's nothing to cancel
     pub quit_on_last_cancel: bool,
 
-    /// number of threads used by file_sum (count, size, date)
-    /// computation
+    /// number of threads used by `file_sum` (count, size, date) computation
     pub file_sum_threads_count: usize,
 
     /// number of files which may be staged in one staging operation
     pub max_staged_count: usize,
 
+    /// whether to automatically open the staging area panel when staging
+    /// a file
+    pub auto_open_staging_area: bool,
+
     /// max file size when searching file content
     pub content_search_max_file_size: usize,
 
@@ -123,11 +137,14 @@ pub struct AppContext {
     /// Whether Kitty keyboard enhancement flags are pushed, so that
     /// we know whether we need to temporarily disable them during
     /// the execution of a terminal program.
-    /// This is determined by app::run on launching the event source.
+    /// This is determined by `app::run` on launching the event source.
     pub keyboard_enhanced: bool,
 
     pub kitty_graphics_transmission: TransmissionMedium,
 
+    /// How Kitty images are displayed
+    pub kitty_graphics_display: KittyGraphicsDisplay,
+
     pub kept_kitty_temp_files: NonZeroUsize,
 
     /// Number of lines to display after a match in the preview
@@ -141,6 +158,9 @@ pub struct AppContext {
 
     /// layout modifiers, like divider moves
     pub layout_instructions: LayoutInstructions,
+
+    /// server name
+    pub server_name: Option<String>,
 }
 
 impl AppContext {
@@ -162,8 +182,7 @@ impl AppContext {
         } else {
             are_true_colors_available()
         };
-        let icons = config.icon_theme.as_ref()
-            .and_then(|itn| icon_plugin(itn));
+        let icons = config.icon_theme.as_ref().and_then(|itn| icon_plugin(itn));
         let mut special_paths: SpecialPaths = (&config.special_paths).try_into()?;
         special_paths.add_defaults();
         let search_modes = config
@@ -172,24 +191,24 @@ impl AppContext {
             .map(TryInto::try_into)
             .transpose()?
             .unwrap_or_default();
-        let ext_colors = ExtColorMap::try_from(&config.ext_colors)
-            .map_err(ConfError::from)?;
-        let file_sum_threads_count = config.file_sum_threads_count
+        let ext_colors = ExtColorMap::try_from(&config.ext_colors).map_err(ConfError::from)?;
+        let file_sum_threads_count = config
+            .file_sum_threads_count
             .unwrap_or(file_sum::DEFAULT_THREAD_COUNT);
         if !(1..=50).contains(&file_sum_threads_count) {
-            return Err(ConfError::InvalidThreadsCount{ count: file_sum_threads_count }.into());
+            return Err(ConfError::InvalidThreadsCount {
+                count: file_sum_threads_count,
+            }
+            .into());
         }
-        let max_panels_count = config.max_panels_count
-            .unwrap_or(2)
-            .clamp(2, 100);
+        let max_panels_count = config.max_panels_count.unwrap_or(2).clamp(2, 100);
         let capture_mouse = match (config.capture_mouse, config.disable_mouse_capture) {
             (Some(b), _) => b, // the new "capture_mouse" argument takes precedence
             (_, Some(b)) => !b,
             _ => true,
         };
-        let max_staged_count = config.max_staged_count
-            .unwrap_or(10_000)
-            .clamp(10, 100_000);
+        let max_staged_count = config.max_staged_count.unwrap_or(10_000).clamp(10, 100_000);
+        let auto_open_staging_area = config.auto_open_staging_area.unwrap_or(true);
         let (initial_root, initial_file) = initial_root_file(&launch_args)?;
 
         // tree options are built from the default_flags
@@ -205,7 +224,8 @@ impl AppContext {
             initial_tree_options.show_selection_mark = true;
         }
 
-        let content_search_max_file_size = config.content_search_max_file_size
+        let content_search_max_file_size = config
+            .content_search_max_file_size
             .map(|u64value| usize::try_from(u64value).unwrap_or(usize::MAX))
             .unwrap_or(content_search::DEFAULT_MAX_FILE_SIZE);
 
@@ -213,9 +233,14 @@ impl AppContext {
         let reset_terminal_title_on_exit = config.reset_terminal_title_on_exit.unwrap_or(false);
         let preview_transformers = PreviewTransformers::new(&config.preview_transformers)?;
         let layout_instructions = config.layout_instructions.clone().unwrap_or_default();
-        let kept_kitty_temp_files = config.kept_kitty_temp_files.unwrap_or(
-            std::num::NonZeroUsize::new(500).unwrap(),
-        );
+        let kept_kitty_temp_files = config
+            .kept_kitty_temp_files
+            .unwrap_or(
+                #[expect(clippy::missing_panics_doc, reason = "infallible")]
+                std::num::NonZeroUsize::new(500).unwrap()
+            );
+        let server_name = build_server_name(&launch_args)
+            .or_else(|| build_server_name(config_default_args.as_ref()?));
 
         Ok(Self {
             is_tty,
@@ -241,27 +266,35 @@ impl AppContext {
             quit_on_last_cancel: config.quit_on_last_cancel.unwrap_or(false),
             file_sum_threads_count,
             max_staged_count,
+            auto_open_staging_area,
             content_search_max_file_size,
             terminal_title_pattern,
             reset_terminal_title_on_exit,
             update_work_dir: config.update_work_dir.unwrap_or(true),
             keyboard_enhanced: false,
-            kitty_graphics_transmission: config.kitty_graphics_transmission
-                .unwrap_or_default(),
+            kitty_graphics_transmission: config.kitty_graphics_transmission.unwrap_or_default(),
+            kitty_graphics_display: config.kitty_graphics_display.unwrap_or_default(),
             kept_kitty_temp_files,
             lines_after_match_in_preview: config.lines_after_match_in_preview.unwrap_or(0),
             lines_before_match_in_preview: config.lines_before_match_in_preview.unwrap_or(0),
             preview_transformers,
             layout_instructions,
+            server_name,
         })
     }
     /// Return the --cmd argument, coming from the launch arguments (preferred)
-    /// or from the default_flags parameter of a config file
+    /// or from the `default_flags` parameter of a config file
     pub fn cmd(&self) -> Option<&str> {
-        self.launch_args.cmd.as_ref().or(
-            self.config_default_args.as_ref().and_then(|args| args.cmd.as_ref())
-        ).map(String::as_str)
+        self.launch_args
+            .cmd
+            .as_ref()
+            .or(self
+                .config_default_args
+                .as_ref()
+                .and_then(|args| args.cmd.as_ref()))
+            .map(String::as_str)
     }
+    #[must_use]
     pub fn initial_mode(&self) -> Mode {
         if self.modal {
             self.initial_mode
@@ -285,10 +318,10 @@ impl Default for AppContext {
 /// try to determine whether the terminal supports true
 /// colors. This doesn't work well, hence the use of an
 /// optional config setting.
-/// Based on https://gist.github.com/XVilka/8346728#true-color-detection
+/// Based on <https://gist.github.com/XVilka/8346728#true-color-detection>
 fn are_true_colors_available() -> bool {
     if let Ok(colorterm) = std::env::var("COLORTERM") {
-        debug!("COLORTERM env variable = {:?}", colorterm);
+        debug!("COLORTERM env variable = {colorterm:?}");
         if colorterm.contains("truecolor") || colorterm.contains("24bit") {
             debug!("true colors are available");
             true
@@ -314,8 +347,9 @@ fn initial_root_file(cli_args: &Args) -> Result<(PathBuf, Option<PathBuf>), Prog
     };
     if !root.exists() {
         return Err(TreeBuildError::FileNotFound {
-            path: format!("{:?}", &root),
-        }.into());
+            path: format!("{root:?}"),
+        }
+        .into());
     }
     if !root.is_dir() {
         // we try to open the parent directory if the passed file isn't one
@@ -326,8 +360,9 @@ fn initial_root_file(cli_args: &Args) -> Result<(PathBuf, Option<PathBuf>), Prog
         } else {
             // this is a weird filesystem, let's give up
             return Err(TreeBuildError::NotADirectory {
-                path: format!("{:?}", &root),
-            }.into());
+                path: format!("{root:?}"),
+            }
+            .into());
         }
     }
     Ok((root, file))
@@ -347,4 +382,17 @@ fn canonicalize_root(root: &Path) -> io::Result<PathBuf> {
     })
 }
 
-
+/// Build a server name according to the launch arguments
+/// (none if there's neither 'listen' nor `listen_auto` arg)
+#[allow(unused_variables)]
+fn build_server_name(args: &Args) -> Option<String> {
+    #[cfg(unix)]
+    if let Some(name) = &args.listen {
+        return Some(name.clone());
+    }
+    #[cfg(unix)]
+    if args.listen_auto {
+        return Some(crate::net::random_server_name());
+    }
+    None
+}
