@@ -38,6 +38,7 @@ pub struct Panel {
 }
 
 impl Panel {
+    #[must_use]
     pub fn new(
         id: PanelId,
         state: Box<dyn PanelState>,
@@ -141,6 +142,7 @@ impl Panel {
             .do_pending_task(app_state, screen, con, dam)
     }
 
+    #[must_use]
     pub fn has_pending_task(&self) -> bool {
         self.state().get_pending_task().is_some()
     }
@@ -150,7 +152,7 @@ impl Panel {
     pub fn add_event(
         &mut self,
         w: &mut W,
-        event: TimedEvent,
+        event: &TimedEvent,
         app_state: &AppState,
         con: &AppContext,
     ) -> Result<Command, ProgramError> {
@@ -168,10 +170,14 @@ impl Panel {
         self.input.set_content(&new_state.get_starting_input());
         self.states.push(new_state);
     }
+    #[must_use]
     pub fn mut_state(&mut self) -> &mut dyn PanelState {
+        #[expect(clippy::missing_panics_doc, reason = "there's always at least one state")]
         self.states.last_mut().unwrap().as_mut()
     }
+    #[must_use]
     pub fn state(&self) -> &dyn PanelState {
+        #[expect(clippy::missing_panics_doc, reason = "there's always at least one state")]
         self.states.last().unwrap().as_ref()
     }
 
@@ -200,6 +206,7 @@ impl Panel {
         self.input.set_content(content);
     }
 
+    #[must_use]
     pub fn get_input_content(&self) -> String {
         self.input.get_content()
     }
@@ -243,6 +250,7 @@ impl Panel {
         if disc.active {
             self.write_purpose(w, disc.panel_skin, disc.screen, disc.con)?;
             let flags = self.state().get_flags();
+            #[allow(clippy::cast_possible_truncation)]
             let input_content_len = self.input.get_content().len() as u16;
             let flags_len = flags_display::visible_width(&flags);
             if input_area.width > input_content_len + 1 + flags_len {
