@@ -2,7 +2,6 @@
 
 use {
     custom_error::custom_error,
-    image::error::ImageError,
     lazy_regex::regex,
     std::io,
 };
@@ -12,8 +11,8 @@ custom_error! {pub ProgramError
     ArgParse {bad: String, valid: String} = "{bad:?} can't be parsed (valid values: {valid:?})",
     ConfFile {path:String, details: ConfError} = "Bad configuration file {path:?} : {details}",
     Conf {source: ConfError} = "Bad configuration: {source}",
-    ImageError {source: ImageError } = "{source}",
-    InternalError {details: String} = "Internal error: {details}", // should not happen
+    ImageError {details: String} = "Image error: {details}",
+    Internal {details: String} = "Internal error: {details}", // should not happen
     Io {source: io::Error} = "IO Error : {source}",
     LaunchError {program: String, source: io::Error} = "Unable to launch {program}: {source}",
     Lfs {details: String} = "Failed to fetch mounts: {details}",
@@ -25,13 +24,14 @@ custom_error! {pub ProgramError
     Termimad {source: termimad::Error} = "Termimad Error : {source}",
     Trash {message: String} = "Trash error: {message}",
     TreeBuild {source: TreeBuildError} = "{source}",
-    UnknowShell {shell: String} = "Unknown shell: {shell}",
+    UnknownShell {shell: String} = "Unknown shell: {shell}",
     UnknownVerb {name: String} = "No verb matches {name:?}",
     UnmappableFile = "File can't be mapped",
     UnmatchingVerbArgs {name: String} = "No matching argument found for verb {name:?}",
     UnprintableFile = "File can't be printed", // has characters that can't be printed without escaping
     Unrecognized {token: String} = "Unrecognized: {token}",
     ZeroLenFile = "File seems empty",
+    Notify { source: notify::Error } = "Notify error: {source}",
 }
 
 custom_error! {pub ShellInstallError
