@@ -1,9 +1,12 @@
 use {
     super::StyleMap,
-    termimad::{Alignment, LineStyle, MadSkin},
+    termimad::{
+        Alignment,
+        LineStyle,
+        MadSkin,
+    },
 };
 
-
 /// build a MadSkin, which will be used for markdown formatting
 /// for the help screen by applying the `help_*` entries
 /// of the skin.
@@ -14,10 +17,7 @@ pub fn make_help_mad_skin(skin: &StyleMap) -> MadSkin {
     ms.code_block.compound_style = ms.inline_code.clone();
     ms.bold = skin.help_bold.clone();
     ms.italic = skin.help_italic.clone();
-    ms.table = LineStyle::new(
-        skin.help_table_border.clone(),
-        Alignment::Center,
-    );
+    ms.table = LineStyle::new(skin.help_table_border.clone(), Alignment::Center);
     if let Some(c) = skin.help_headers.get_fg() {
         ms.set_headers_fg(c);
     }
@@ -34,4 +34,3 @@ pub fn make_help_mad_skin(skin: &StyleMap) -> MadSkin {
         .set_compound_style(skin.scrollbar_thumb.clone());
     ms
 }
-
