@@ -1,6 +1,10 @@
 use {
     super::StyleMap,
-    termimad::{Alignment, LineStyle, MadSkin},
+    termimad::{
+        Alignment,
+        LineStyle,
+        MadSkin,
+    },
 };
 
 /// the mad skin applying to the status depending whether it's an
@@ -14,10 +18,7 @@ pub struct StatusMadSkinSet {
 /// when there's no error
 fn make_normal_status_mad_skin(skin: &StyleMap) -> MadSkin {
     MadSkin {
-        paragraph: LineStyle::new(
-            skin.status_normal.clone(),
-            Alignment::Left,
-        ),
+        paragraph: LineStyle::new(skin.status_normal.clone(), Alignment::Left),
         italic: skin.status_italic.clone(),
         bold: skin.status_bold.clone(),
         inline_code: skin.status_code.clone(),
@@ -30,10 +31,7 @@ fn make_normal_status_mad_skin(skin: &StyleMap) -> MadSkin {
 /// when there's a error
 fn make_error_status_mad_skin(skin: &StyleMap) -> MadSkin {
     MadSkin {
-        paragraph: LineStyle::new(
-            skin.status_error.clone(),
-            Alignment::Left,
-        ),
+        paragraph: LineStyle::new(skin.status_error.clone(), Alignment::Left),
         ellipsis: skin.status_ellipsis.clone(),
         ..Default::default()
     }
@@ -47,4 +45,3 @@ impl StatusMadSkinSet {
         }
     }
 }
-
