@@ -1,16 +1,13 @@
-
 mod trash_sort;
 mod trash_state;
 mod trash_state_cols;
 
 pub use trash_state::*;
 
-use {
-    trash::{
-        self as trash_crate,
-        TrashItem,
-        TrashItemSize,
-    },
+use trash::{
+    self as trash_crate,
+    TrashItem,
+    TrashItemSize,
 };
 
 /// Determine whether an item in the trash is a directory.
@@ -18,12 +15,10 @@ use {
 /// There's probably a simpler solution in the trash crate, but I didn't found it.
 fn item_is_dir(item: &TrashItem) -> bool {
     match trash_crate::os_limited::metadata(item) {
-        Ok(metadata) => {
-            match metadata.size {
-                TrashItemSize::Bytes(_) => false,
-                TrashItemSize::Entries(_) => true,
-            }
-        }
+        Ok(metadata) => match metadata.size {
+            TrashItemSize::Bytes(_) => false,
+            TrashItemSize::Entries(_) => true,
+        },
         Err(_) => false,
     }
 }
