@@ -6,14 +6,18 @@ use {
         browser::BrowserState,
         command::TriggerType,
         display::Screen,
-        path::{self, PathAnchor},
+        path::{
+            self,
+            PathAnchor,
+        },
         pattern::InputPattern,
         preview::PreviewState,
         task_sync::Dam,
         tree::TreeOptions,
     },
-    std::{
-        path::{Path, PathBuf},
+    std::path::{
+        Path,
+        PathBuf,
     },
 };
 
@@ -107,7 +111,7 @@ fn path_from_input(
 ) -> PathBuf {
     match (input_arg, internal_exec.arg.as_ref()) {
         (Some(input_arg), Some(verb_arg)) => {
-            // The verb probably defines some patttern which uses the input.
+            // The verb probably defines some pattern which uses the input.
             // For example:
             // {
             //     invocation: "gotar {path}"
@@ -161,9 +165,7 @@ pub fn get_status_markdown(
     app_state: &AppState,
     con: &AppContext,
 ) -> String {
-    let base_path = sel_info
-        .one_path()
-        .unwrap_or(&app_state.root);
+    let base_path = sel_info.one_path().unwrap_or(&app_state.root);
     let path = path_from_input(
         verb,
         internal_exec,
@@ -185,15 +187,16 @@ pub fn on_internal(
     selected_path: &Path,
     is_root_selected: bool,
     tree_options: TreeOptions,
-    app_state: & AppState,
+    app_state: &AppState,
     cc: &CmdContext,
 ) -> CmdResult {
     let con = &cc.app.con;
     let screen = cc.app.screen;
     let bang = input_invocation
-            .map(|inv| inv.bang)
-            .unwrap_or(internal_exec.bang);
-    let input_arg = input_invocation.as_ref()
+        .map(|inv| inv.bang)
+        .unwrap_or(internal_exec.bang);
+    let input_arg = input_invocation
+        .as_ref()
         .and_then(|invocation| invocation.args.as_ref());
     match trigger_type {
         TriggerType::Input(verb) => {
