@@ -157,14 +157,14 @@ impl VerbStore {
         )
         .with_shortcut("cpp");
         self.add_internal(trash);
-        #[cfg(trash)]
+        #[cfg(any(target_os = "windows", all(unix, not(any(target_os = "ios", target_os = "android")))))]
         {
             self.add_internal(open_trash).with_shortcut("ot");
             self.add_internal(restore_trashed_file).with_shortcut("rt");
             self.add_internal(delete_trashed_file).with_shortcut("dt");
             self.add_internal(purge_trash).with_shortcut("et");
         }
-        #[cfg(unix)]
+        #[cfg(any(target_os = "macos", target_os = "linux", target_os = "windows"))]
         self.add_internal(filesystems).with_shortcut("fs");
         self.add_internal(focus_staging_area_no_open);
         // :focus is also hardcoded on Enter on directories
